graphene-extenstions
====================

.. image:: https://travis-ci.org/karol-gruszczyk/graphene-extenstions.svg?branch=master
    :target: https://travis-ci.org/karol-gruszczyk/graphene-extenstions
    :alt: Build

.. image:: https://coveralls.io/repos/github/karol-gruszczyk/graphene-extenstions/badge.svg?branch=master
    :target: https://coveralls.io/github/karol-gruszczyk/graphene-extenstions?branch=master
    :alt: Coverage


Goal of this library is to make development on graphene a lot simpler
and quicker, which means less boiler plate and more flexibility.

Requirements
------------

-  Python 3.6+
-  graphene 2.0+
-  Django 1.10+

More info
---------

`GitHub <https://github.com/karol-gruszczyk/graphene-extenstions/>`__
